@@ -8,6 +8,11 @@ class objearth():
         pass
     @staticmethod
     def montage(img1,img2):
+        """
+        montage with 2 image image1,image2
+        :param img1: image 1 numpy array
+        :param img2: image 2 numpy array
+        """
         plt.figure(figsize=(15,15))
         plt.subplot(121),plt.imshow(img1, cmap = 'gray')
         plt.title('Image 1'), plt.xticks([]), plt.yticks([])
@@ -16,6 +21,12 @@ class objearth():
         plt.show()
     @staticmethod
     def falsecolor(Dataset1,Dataset2,Dataset3,bright=10):
+        """
+        color combination with xarray data
+        :param Dataset1: band 1
+        :param Dataset1: band 2
+        :param Dataset3: band 3
+        """
         BAND1    = xarray.where(Dataset1==-9999,numpy.nan,Dataset1)
         band1    = BAND1.to_numpy()/10000*bright
         BAND2    = xarray.where(Dataset2==-9999,numpy.nan,Dataset2)
@@ -235,6 +246,15 @@ class objearth():
         green  = GREEN/10000 *bright
         blue   = BLUE/10000  *bright
         return numpy.stack([red,green,blue],axis=2)
+
     @staticmethod
     def bandopen(target):
-        return gdal.Open(target).ReadAsArray()
\ No newline at end of file
+        return gdal.Open(target).ReadAsArray()
+    
+    @staticmethod
+    def genguasian(size1,size2):
+        x, y = numpy.meshgrid(numpy.linspace(-1,1,size1), numpy.linspace(-1,1,size2))
+        d = numpy.sqrt(x*x+y*y)
+        sigma, mu = 0.5, 1.0
+        g = numpy.exp(-( (d-mu)**2 / ( 2.0 * sigma**2 ) ) )
+        return g
\ No newline at end of file
